==> tkvoice-1.2a.tar.gz: tkvoice-1.2a/TCL/tkvprintfax.tcl <==
# tkvprintfax.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvprintfax
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Print FAX"
wm iconname $w "tkVoice Print FAX"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global tkvoicedir userhome FAX PAGE PAGET printcmd printsel faxdpi

# Defaults
set PRINTTO "printer"
set PORDER "last"
set FPATH "~/tkvoice.ps"
set PRINT "$printcmd $printsel"
set ALL 1

# START PROCS Section
proc printgo {} {
global w userhome faxdpi FAX PAGET PRINTTO FPATH PRINT PORDER ALL FROM TO

catch { exec rm $userhome/tkvoice.ps }
# PRINTTO printer:file
# PRINT (holds printcmd & printsel)
# PORDER first:last
# ALL 1:0
# PF=print first 2-digit number
# PB=print first real int
# PN=print page 2-digit number
# PP=print page real int
# PL=print last 2-digit number
# PS=print last real int 

if {$ALL == "1"} {
 set PF 01
 set PL $PAGET
} elseif {$ALL == "0"} {
 set PF $FROM
 set PL $TO
}

if {[string range $PF 0 0] == "0"} {
 set PB [string range $PF 1 1]
} else {
 set PB $PF
}
if {[string range $PL 0 0] == "0"} {
 set PS [string range $PL 1 1]
} else {
 set PS $PL
}

set GO "1"
############################# first pg first #################################
if {$PORDER == "first"} {
   set PP $PB
   while {$GO == "1"} {
     if {$PP < 10} {
        set PN "0"
        append PN $PP
        } else {
        set PN $PP
        }  
     catch { exec ls $FAX.$PN } test
     if { $test == "$FAX.$PN" } {
       eval exec g32pbm $FAX.$PN | pbmtolps -dpi $faxdpi >> $userhome/tkvoice.ps
     }
      if {$PP == $PS} {
      set GO "0"
      } else {
      set PP [expr $PP+1]
      }
   }
}
############################# first pg last #################################
if {$PORDER == "last"} {
   set PP $PS
   while {$GO == "1"} {
     if {$PP < 10} {
       set PN "0"
       append PN $PP
     } else {
       set PN $PP
     }  
     catch { exec ls $FAX.$PN } test
     if { $test == "$FAX.$PN" } {
       eval exec g32pbm $FAX.$PN | pbmtolps -dpi $faxdpi >> $userhome/tkvoice.ps
     }
     if {$PP == $PB} {
     set GO "0"
     } else {
     set PP [expr $PP-1]
     }
   }
 }
# PRINTTO printer:file
 if {$PRINTTO == "printer"} {
    eval exec $PRINT $userhome/tkvoice.ps
 }
 if {$PRINTTO == "file"} {
    if {[string range $FPATH 0 0] == "~"} {
       set PWDTMP [pwd]
       cd ~
       set HOME [pwd]
       cd $PWDTMP
       set TAIL [string range $FPATH 1 end]
       set FPATH $HOME
       append FPATH $TAIL
    }
    exec mv $userhome/tkvoice.ps $FPATH
 }
destroy $w
}


# END PROCS Section

# START TOP IMAGE ##############################################
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoiceprintfax}
image create photo tkvoiceprintfax -file [file join $tkvoicedir/image/tkvoiceprintfax.gif]
label $w.gif.tkvoiceprintfax -image tkvoiceprintfax -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoiceprintfax -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right
# END TOP IMAGE ##############################################


frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.print -text PRINT -command "printgo"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.print $w.buttons.cancel -side left -expand 1

# Split the window into left and right sides
frame $w.right
pack $w.right -side left -expand yes -pady .25c -padx .25c

############## Choose printer or file ############################
frame $w.right.r1
pack $w.right.r1 -side top


radiobutton $w.right.r1.printer -text "Printer" -variable PRINTTO -value printer
radiobutton $w.right.r1.file -text "File                               " -variable PRINTTO -value file
pack $w.right.r1.printer $w.right.r1.file  -expand 1 -fill y -side left -pady 6

frame $w.right.r1l
pack $w.right.r1l -side top -expand yes -pady 6 -padx 2
label $w.right.r1l.floc -justify left -text "File Location:                                      "
entry $w.right.r1l.fpath -relief sunken -width 32 -textvariable FPATH \
                        -background snow2
pack $w.right.r1l.floc $w.right.r1l.fpath -side top -expand yes

######## Choose Print command ######################################

frame $w.right.r2
pack $w.right.r2 -side top -expand yes -pady 6 -padx 2
label $w.right.r2.printcmd -justify left -text "Print Command:                                  "
entry $w.right.r2.cmdentry -relief sunken -width 32 -textvariable PRINT \
                           -background snow2
pack $w.right.r2.printcmd $w.right.r2.cmdentry -side top -expand yes

######### Choose Print Order #####################################

frame $w.right.r3
pack $w.right.r3 -side top -expand yes -pady 6 -padx 2

radiobutton $w.right.r3.first -text "First Page First" -variable PORDER -value first
radiobutton $w.right.r3.last -text "Last Page First" -variable PORDER -value last
pack $w.right.r3.first $w.right.r3.last -side left -expand yes

######## Choose ALL or Range ##################################

frame $w.right.r4
pack $w.right.r4 -side top -expand yes -pady 2 -padx 2

radiobutton $w.right.r4.all -text "All Pages" -variable ALL -value 1
radiobutton $w.right.r4.range -text "Range of Pages        " -variable ALL -value 0
pack $w.right.r4.all $w.right.r4.range -side left -expand yes

frame $w.right.r4l
pack $w.right.r4l -side top -expand yes -pady 2 -padx 2

label $w.right.r4l.from -font $font -justify right -text "             From:"
entry $w.right.r4l.fenter -relief sunken -width 2 -textvariable FROM \
                         -background snow2
label $w.right.r4l.to -font $font -justify right -text "To:"
entry $w.right.r4l.tenter -relief sunken -width 2 -textvariable TO \
                         -background snow2
pack $w.right.r4l.from $w.right.r4l.fenter $w.right.r4l.to $w.right.r4l.tenter \
     -side left -expand yes

==> tkvoice-1.3.tar.gz: tkvoice-1.3/TCL/tkvprintfax.tcl <==
# tkvprintfax.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvprintfax
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Print FAX"
wm iconname $w "tkVoice Print FAX"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global tkvoicedir userhome FAX PAGE PAGET printcmd printsel faxdpi
set bgcolor "#eeeeee"

##################################################

# Defaults
set PRINTTO "printer"
set PORDER "last"
set FPATH "~/tkvoice.ps"
set PRINT "$printcmd $printsel"
set ALL 1

# START PROCS Section
proc printgo {} {
global w userhome faxdpi FAX PAGET PRINTTO FPATH PRINT PORDER ALL FROM TO

catch { exec rm $userhome/tkvoice.ps }
if {$FAX != ""} {
# PRINTTO printer:file
# PRINT (holds printcmd & printsel)
# PORDER first:last
# ALL 1:0
# PF=print first 2-digit number
# PB=print first real int
# PN=print page 2-digit number
# PP=print page real int
# PL=print last 2-digit number
# PS=print last real int 

if {$ALL == "1"} {
 set PF 01
 set PL $PAGET
} elseif {$ALL == "0"} {
 set PF $FROM
 set PL $TO
}

if {[string range $PF 0 0] == "0"} {
 set PB [string range $PF 1 1]
} else {
 set PB $PF
}
if {[string range $PL 0 0] == "0"} {
 set PS [string range $PL 1 1]
} else {
 set PS $PL
}

set GO "1"
############################# first pg first #################################
if {$PORDER == "first"} {
   set PP $PB
   while {$GO == "1"} {
     if {$PP < 10} {
        set PN "0"
        append PN $PP
        } else {
        set PN $PP
        }  
     catch { exec ls $FAX.$PN } test
     if { $test == "$FAX.$PN" } {
       eval exec g32pbm $FAX.$PN | pbmtolps -dpi $faxdpi >> $userhome/tkvoice.ps
     }
      if {$PP == $PS} {
      set GO "0"
      } else {
      set PP [expr $PP+1]
      }
   }
}
############################# first pg last #################################
if {$PORDER == "last"} {
   set PP $PS
   while {$GO == "1"} {
     if {$PP < 10} {
       set PN "0"
       append PN $PP
     } else {
       set PN $PP
     }  
     catch { exec ls $FAX.$PN } test
     if { $test == "$FAX.$PN" } {
       eval exec g32pbm $FAX.$PN | pbmtolps -dpi $faxdpi >> $userhome/tkvoice.ps
     }
     if {$PP == $PB} {
     set GO "0"
     } else {
     set PP [expr $PP-1]
     }
   }
 }
# PRINTTO printer:file
 if {$PRINTTO == "printer"} {
    eval exec $PRINT $userhome/tkvoice.ps
 }
 if {$PRINTTO == "file"} {
    if {[string range $FPATH 0 0] == "~"} {
       set PWDTMP [pwd]
       cd ~
       set HOME [pwd]
       cd $PWDTMP
       set TAIL [string range $FPATH 1 end]
       set FPATH $HOME
       append FPATH $TAIL
    }
    exec mv $userhome/tkvoice.ps $FPATH
  }
destroy $w
 }
}


# END PROCS Section

# START TOP IMAGE ##############################################
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoiceprintfax}
image create photo tkvoiceprintfax -file [file join $tkvoicedir/image/tkvoiceprintfax.gif]
label $w.gif.tkvoiceprintfax -image tkvoiceprintfax -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoiceprintfax -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right
# END TOP IMAGE ##############################################


frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.print -text PRINT -command "printgo"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.print $w.buttons.cancel -side left -expand 1

# Split the window into left and right sides
frame $w.right
pack $w.right -side left -expand yes -pady .25c -padx .25c

############## Choose printer or file ############################
frame $w.right.r1
pack $w.right.r1 -side top


radiobutton $w.right.r1.printer -text "Printer" -variable PRINTTO -value printer
radiobutton $w.right.r1.file -text "File" -anchor w -width 20 -variable PRINTTO -value file
pack $w.right.r1.printer $w.right.r1.file  -expand 1 -fill y -side left -pady 6

frame $w.right.r1l
pack $w.right.r1l -side top -expand yes -pady 6 -padx 2
label $w.right.r1l.floc -justify left -text "File Location:" -width 33 -anchor w
entry $w.right.r1l.fpath -relief sunken -width 32 -textvariable FPATH \
                        -background $bgcolor
pack $w.right.r1l.floc $w.right.r1l.fpath -side top -expand yes

######## Choose Print command ######################################

frame $w.right.r2
pack $w.right.r2 -side top -expand yes -pady 6 -padx 2
label $w.right.r2.printcmd -justify left -text "Print Command:" -width 33 -anchor w
entry $w.right.r2.cmdentry -relief sunken -width 32 -textvariable PRINT \
                           -background $bgcolor
pack $w.right.r2.printcmd $w.right.r2.cmdentry -side top -expand yes

######### Choose Print Order #####################################

frame $w.right.r3
pack $w.right.r3 -side top -expand yes -pady 6 -padx 2

radiobutton $w.right.r3.first -text "First Page First" -variable PORDER -value first
radiobutton $w.right.r3.last -text "Last Page First" -variable PORDER -value last
pack $w.right.r3.first $w.right.r3.last -side left -expand yes

######## Choose ALL or Range ##################################

frame $w.right.r4
pack $w.right.r4 -side top -expand yes -pady 2 -padx 2

radiobutton $w.right.r4.all -text "All Pages" -variable ALL -value 1
radiobutton $w.right.r4.range -text "Range of Pages" -width 18 -anchor w -variable ALL -value 0
pack $w.right.r4.all $w.right.r4.range -side left -expand yes

frame $w.right.r4l
pack $w.right.r4l -side top -expand yes -pady 2 -padx 2

label $w.right.r4l.from -font $font -justify right -text "From:" -width 15 -anchor e
entry $w.right.r4l.fenter -relief sunken -width 2 -textvariable FROM \
                         -background $bgcolor
label $w.right.r4l.to -font $font -justify right -text "To:"
entry $w.right.r4l.tenter -relief sunken -width 2 -textvariable TO \
                         -background $bgcolor
pack $w.right.r4l.from $w.right.r4l.fenter $w.right.r4l.to $w.right.r4l.tenter \
     -side left -expand yes
